@@ -249,7 +249,7 @@ class MDS:
             default_bucket
         )
 
-    def call_model_convert_path_status(self, data:Dict[str, Any]) -> None:
+    def call_model_convert_path_status(self, data: Dict[str, Any]) -> None:
         """callback modelConvert path and status.
 
         Arguments:
@@ -262,7 +262,38 @@ class MDS:
                 is_arm:  是否是arm模型 
 
         """
-        if data.get("mpid") == None:
-             raise InvalidParamsError(message="mid not blank")
+        if data.get("mpid") is None:
+            raise InvalidParamsError(message="mid not blank")
         info = self._x_api.call_model_convert_path_status(data)
         return info
+
+    def call_model_test_status(self, data: Dict[str, Any]) -> None:
+        """callback modelTest status.
+
+        Arguments:
+            data: The data of the requested json
+                mtid:  模型测试id
+                result_path: 测试结果路径,
+                eval_content: 模型测试eval内容,
+                perform_content: 模型测试perform内容,
+                status: 转换状态
+
+        """
+        if data.get("mtid") is None:
+            raise InvalidParamsError(message="mid not blank")
+        info = self._x_api.call_model_test_status(data)
+        return info
+
+    def call_model_test_result_content(self, data: Dict[str, Any]) -> None:
+        """callback modelTestResult content..
+
+        Arguments:
+            data: The data of the requested json
+                tid:  模型测试id
+                content: 模型测试内容,
+
+        """
+        if data.get("tid") is None:
+            raise InvalidParamsError(message="mid not blank")
+        info = self._x_api.call_model_test_result_content(data)
+        return info
