@@ -346,3 +346,17 @@ class X_API:
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_convert/path/callback", "", json=post_data).json()
         return response
+
+    def call_model_test_status(
+             self,
+             post_data: str
+    ) -> Dict[str, Any]:
+        response = self._client.open_api_do("PUT", "model_test/status/callback", "", json=post_data).json()
+        return response
+
+    def call_model_test_result_content(
+            self,
+            post_data: str
+    ) -> Dict[str, Any]:
+        response = self._client.open_api_do("PUT", "model_test_result/content/callback", "", json=post_data).json()
+        return response
